import logging
import logging.config
import os


LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '[%(asctime)s] [%(levelname)s] %(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose'
        },
    },
    'loggers': {
        '': {
            'level': os.getenv('LOG_LEVEL', 'ERROR'),
            'handlers': ['console'],
        },
        'eds': {
            'level': os.getenv('LOG_LEVEL', 'ERROR'),
            'handlers': ['console'],
            'propagate': False,
        },
    },
}


def init():
    logging.config.dictConfig(LOGGING)
    logging.getLogger('urllib3').propagate = False
    logging.getLogger('google').propagate = False


class DummyCLI:
    """A dummy CLI which implements the CLI methods we need.
    Yet does nothing.
    """
    def done(self, *args, **kwargs):
        pass

    def log(self, *args, **kwargs):
        pass

    def progress(self, *args, **kwargs):
        pass


class FlaskCLI(DummyCLI):
    """A CLI implementation for Flask."""
    def __init__(self, logger):
        self.logger = logger

    def log(self, message):
        self.logger.info(message)
